package com.jeethink.web.controller.system;

import java.util.HashMap;
import java.util.List;
import java.util.Set;

import com.jeethink.common.utils.MD5Utils;
import com.jeethink.system.service.ISysUserService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RestController;

import com.jeethink.common.constant.Constants;
import com.jeethink.common.core.domain.AjaxResult;
import com.jeethink.common.core.domain.entity.SysMenu;
import com.jeethink.common.core.domain.entity.SysUser;
import com.jeethink.common.core.domain.model.LoginBody;
import com.jeethink.common.core.domain.model.LoginUser;
import com.jeethink.common.utils.ServletUtils;
import com.jeethink.framework.web.service.SysLoginService;
import com.jeethink.framework.web.service.SysPermissionService;
import com.jeethink.framework.web.service.TokenService;
import com.jeethink.system.service.ISysMenuService;

/**
 * 登录验证
 * 
 * @author jeethink
 */
@RestController
public class SysLoginController
{
    @Autowired
    private SysLoginService loginService;

    @Autowired
    private ISysMenuService menuService;

    @Autowired
    private SysPermissionService permissionService;

    @Autowired
    private TokenService tokenService;

    @Autowired
    private ISysUserService userService;

    /**
     * 登录方法
     * 
     * @param loginBody 登录信息
     * @return 结果
     */
    @PostMapping("/login")
    public AjaxResult login(@RequestBody LoginBody loginBody)
    {
        AjaxResult ajax = AjaxResult.success();
        // 生成令牌
        String token = loginService.login(loginBody.getUsername(), loginBody.getPassword(), loginBody.getCode(),
                loginBody.getUuid());
        ajax.put(Constants.TOKEN, token);
        return ajax;
    }

    //人力系统单点登录后台接口
    @PostMapping("/login/human")
    public AjaxResult humanLogin(@RequestBody HashMap data){
        AjaxResult ajax = AjaxResult.success();
        String token="";
        String userNum = (String) data.get("userNum");
        String timestamp = (String) data.get("timestamp");
        String str = (String) data.get("str");
        String humanToken = (String) data.get("token");
        String realToken= MD5Utils.stringToMD5(userNum+timestamp+str);
        if(realToken.equals(humanToken)){
            HashMap account=userService.selectAccount(userNum);
            String userName= (String) account.get("userName");
            String password= (String) account.get("password");
            // 生成令牌
            token = loginService.login(userName,password,null,"");
            ajax.put(Constants.TOKEN, token);
            return ajax;
        }else{
            return AjaxResult.error();
        }

    }



    /**
     * 获取用户信息
     * 
     * @return 用户信息
     */
    @GetMapping("getInfo")
    public AjaxResult getInfo()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        SysUser user = loginUser.getUser();
        // 角色集合
        Set<String> roles = permissionService.getRolePermission(user);
        // 权限集合
        Set<String> permissions = permissionService.getMenuPermission(user);
        AjaxResult ajax = AjaxResult.success();
        ajax.put("user", user);
        ajax.put("roles", roles);
        ajax.put("permissions", permissions);
        return ajax;
    }

    /**
     * 获取路由信息
     * 
     * @return 路由信息
     */
    @GetMapping("getRouters")
    public AjaxResult getRouters()
    {
        LoginUser loginUser = tokenService.getLoginUser(ServletUtils.getRequest());
        // 用户信息
        SysUser user = loginUser.getUser();
        List<SysMenu> menus = menuService.selectMenuTreeByUserId(user.getUserId());
        return AjaxResult.success(menuService.buildMenus(menus));
    }
}
