package com.jeethink.system.service.impl;

import com.jeethink.system.domain.SystemFile;
import com.jeethink.system.mapper.SystemFileMapper;
import com.jeethink.system.service.ISystemFileService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 文件库Service业务层处理
 * 
 * @author jeethink
 * @date 2022-03-24
 */
@Service
public class SystemFileServiceImpl implements ISystemFileService 
{
    @Autowired
    private SystemFileMapper systemFileMapper;

    /**
     * 查询文件库
     * 
     * @param fileId 文件库ID
     * @return 文件库
     */
    @Override
    public SystemFile selectSystemFileById(String fileId)
    {
        return systemFileMapper.selectSystemFileById(fileId);
    }

    /**
     * 查询文件库列表
     * 
     * @param systemFile 文件库
     * @return 文件库
     */
    @Override
    public List<SystemFile> selectSystemFileList(SystemFile systemFile)
    {
        return systemFileMapper.selectSystemFileList(systemFile);
    }

    /**
     * 新增文件库
     * 
     * @param systemFile 文件库
     * @return 结果
     */
    @Override
    public int insertSystemFile(SystemFile systemFile)
    {
        return systemFileMapper.insertSystemFile(systemFile);
    }

    /**
     * 修改文件库
     * 
     * @param systemFile 文件库
     * @return 结果
     */
    @Override
    public int updateSystemFile(SystemFile systemFile)
    {
        return systemFileMapper.updateSystemFile(systemFile);
    }

    /**
     * 批量删除文件库
     * 
     * @param fileIds 需要删除的文件库ID
     * @return 结果
     */
    @Override
    public int deleteSystemFileByIds(String[] fileIds)
    {
        return systemFileMapper.deleteSystemFileByIds(fileIds);
    }

    /**
     * 删除文件库信息
     * 
     * @param fileId 文件库ID
     * @return 结果
     */
    @Override
    public int deleteSystemFileById(String fileId)
    {
        return systemFileMapper.deleteSystemFileById(fileId);
    }
}
